@@ -301,7 +301,7 @@ our %EXPORT_TAGS = (
     constant    => [
         qw(
             TNT_INSERT TNT_SELECT TNT_UPDATE TNT_DELETE TNT_CALL TNT_PING
-            TNT_FLAG_RETURN TNT_FLAG_ADD TNT_FLAG_REPLACE TNT_FLAG_BOX_QUIET
+            TNT_FLAG_RETURN TNT_FLAG_ADD TNT_FLAG_REPLACE
         )
     ],
 );
@@ -309,7 +309,7 @@ our %EXPORT_TAGS = (
 our @EXPORT_OK = ( map { @$_ } values %EXPORT_TAGS );
 $EXPORT_TAGS{all} = \@EXPORT_OK;
 our @EXPORT = @{ $EXPORT_TAGS{client} };
-our $VERSION = '0.39';
+our $VERSION = '0.40';
 
 =head1 EXPORT
 
@@ -330,6 +330,23 @@ sub tarantool {
 }
 
 
+=head2 rsync_tarantool
+
+connects to L<Tarantool|http://tarantool.org> in synchronous mode
+using L<DR::Tarantool::RealSyncClient>.
+
+=cut
+
+sub rsync_tarantool {
+    require DR::Tarantool::RealSyncClient;
+    no warnings 'redefine';
+    *rsync_tarantool = sub {
+        DR::Tarantool::RealSyncClient->connect(@_);
+    };
+    goto \&rsync_tarantool;
+}
+
+
 =head2 async_tarantool
 
 connects to L<tarantool|http://tarantool.org> in async mode using
